@@ -59,7 +59,7 @@ def preprocess_single(fn, satname, cloud_mask_issue, pan_off, collection):
         if True, disable panchromatic sharpening and ignore pan band
     collection: str
         Landsat collection ,'C01' or 'C02'
-        
+
     Returns:
     -----------
     im_ms: np.array
@@ -502,7 +502,7 @@ def rescale_image_intensity(im, cloud_mask, prob_high):
 
     return im_adj
 
-def create_jpg(im_ms, cloud_mask, date, satname, filepath, create_plt:bool=True):
+def create_jpg(im_ms, cloud_mask, date, satname, filepath, create_plot:bool=True):
     """
     Saves a .jpg file with the RGB image as well as the NIR and SWIR1 grayscale images.
     This functions can be modified to obtain different visualisations of the
@@ -520,7 +520,7 @@ def create_jpg(im_ms, cloud_mask, date, satname, filepath, create_plt:bool=True)
         string containing the date at which the image was acquired
     satname: str
         name of the satellite mission (e.g., 'L5')
-    create_plt: bool
+    create_plot: bool
         create a matplot lib containing the image with the datatime as the title
 
     Returns:
@@ -529,7 +529,7 @@ def create_jpg(im_ms, cloud_mask, date, satname, filepath, create_plt:bool=True)
 
     """
     
-    if create_plt == True:
+    if create_plot == True:
         # rescale image intensity for display purposes
         im_RGB = rescale_image_intensity(im_ms[:,:,[2,1,0]], cloud_mask, 99.9)
         # im_NIR = rescale_image_intensity(im_ms[:,:,3], cloud_mask, 99.9)
@@ -568,7 +568,7 @@ def create_jpg(im_ms, cloud_mask, date, satname, filepath, create_plt:bool=True)
         # save figure
         fig.savefig(os.path.join(filepath, date + '_' + satname + '.jpg'), dpi=150)
         plt.close()
-    elif create_plt == False:
+    elif create_plot == False:
         # rescale image intensity for display purposes
         im_RGB = rescale_image_intensity(im_ms[:,:,[2,1,0]], cloud_mask, 99.9)
         im_NIR = rescale_image_intensity(im_ms[:,:,3], cloud_mask, 99.9)
@@ -592,12 +592,6 @@ def create_jpg(im_ms, cloud_mask, date, satname, filepath, create_plt:bool=True)
                 imsave(fname, im_SWIR)
             if ext == "NIR":
                 imsave(fname, im_NIR)
-        # # Save swir image with skimage.io
-        # fname=os.path.join(filepath, date + '_SWIR_' + satname + '.jpg')
-        # imsave(fname, im_SWIR)
-        # # Save nir image with skimage.io
-        # fname=os.path.join(filepath, date + '_NIR_' + satname + '.jpg')
-        # imsave(fname, im_NIR)
 
 def save_jpg(metadata, settings, **kwargs):
     """
@@ -644,7 +638,6 @@ def save_jpg(metadata, settings, **kwargs):
     # loop through satellite list
     print('Saving images as jpg:')
     for satname in metadata.keys():
-        
         filepath = SDS_tools.get_filepath(settings['inputs'],satname)
         filenames = metadata[satname]['filenames']
         print('%s: %d images'%(satname,len(filenames)))
@@ -674,7 +667,7 @@ def save_jpg(metadata, settings, **kwargs):
             # save .jpg with date and satellite in the title
             date = filenames[i][:19]
             plt.ioff()  # turning interactive plotting off
-            create_jpg(im_ms, cloud_mask, date, satname, filepath_jpg, create_plt)
+            create_jpg(im_ms, cloud_mask, date, satname, filepath_jpg, create_plot)
         print('')
     # print the location where the images have been saved
     print('Satellite images saved as .jpg in ' + os.path.join(filepath_data, sitename,
